# -*- coding: utf-8 -*-
"""
第218回農林交流センターWS「メッシュ農業気象データ利用講習会」 
実習：Pythonによるメッシュ農業気象データの処理１

"""
#Pythonに機能を追加するために外部モジュールをインポートします。
import numpy as np               #配列計算を高速に実行するためのモジュール
import AMD_Tools3 as AMD         #メッシュ農業気象データを利用するためのモジュール


def Aet(T,ts,tcc0=False):                                      # 　   <--------
    """
    aet:有効積算気温を計算する関数
    説明文、引数、戻り値、使用例などの記入する。
    """    
    Tc = T - ts                                                
    Tc0 = np.maximum(Tc, 0)                                    
    if tcc0: Tc0[0] = 0                                        # 　   <--------                                                
    Tcc = np.cumsum(Tc0, axis=0)                               
    return Tcc                                                 # 　   <--------    

#ちょっと奇妙ですが、プログラムの本文は次の文で始めます。
if __name__ == "__main__":

    # 取得する気象要素の指定
    #  気象要素は、文字列で指定します。 
    nani = "TMP_mea"

    # データを取得する期間の指定
    #  2018年5月1日から7月31日までのデータを取得するには以下のように期間を指定します。
    itsu = ["2018-05-01", "2018-09-30" ]

    # 対象とする地点の指定
    #  北緯36.0566度,東経140.125度の地点を含むメッシュのデータを取得するには場所を以下のように指定します。
    doko = [ 36.0566, 36.0566, 140.125, 140.125]	#つくば(舘野)

    # 気象データの取得
    #　　気象データを取得するGetMetData関数の括弧の中に上記の変数を指定し、右辺に置きます。
    #　　左辺には関数の戻り値を置きます。順に、気象データ、日付、緯度、経度が格納されます。
    met, tim, lat, lon = AMD.GetMetData(nani, itsu, doko, url='./AMD')	#気象データを取得
    T = met[:,0,0]  #気象データは常に三次元(日付、緯度、経度)の入れ物に入れられて返されます。それを1次元(日付)の入れ物に入れ替えます。名前は一緒で構いません。
    ntim = len(tim)  #何日分の気象データかを数えます。
    
    #有効積算気温の設定
    ts = 10.0             #基準温度
    tccx = 950.0          #有効積算気温の上限値

    #有効積算気温の計算
    #初日から有効積算気温を計算する場合は、第3引数を省略する、または、False、None、0、空の文字列を与える。
    #初日の有効積算気温を0にする場合は、第3引数に、True、0以外の数値、文字列を与える。    
    Tcc = Aet(T, ts, 1)                                        #     <--------        
    
    #有効積算気温が950℃日を超える日を表示
    for t in range(0, ntim):
        print("---", t, tim[t], T[t], Tcc[t] )
        if tccx <= Tcc[t]:
            break                                #ループ脱出      
    print()
    print(tim[t])                     

"""
次を実行してみよう。
run aet6


ステップアップ３
別ファイルから、有効積算気温の関数をインポートする方法をご紹介します。

aet7.pyを開きましょう。
"""


