# -*- coding: utf-8 -*-
"""
第218回農林交流センターWS「メッシュ農業気象データ利用講習会」 
実習：Pythonによるメッシュ農業気象データの処理２

１）「単一地点の」有効積算気温を計算し（前パートと同一）
２）有効積算気温の推移をグラフで描画し
３）テキストをcsvファイルとして出力する。

"""
#Pythonに機能を追加するために外部モジュールをインポートします。
import numpy as np               #配列計算を高速に実行するためのモジュール
import AMD_Tools3 as AMD         #メッシュ農業気象データを利用するためのモジュール
import matplotlib.pyplot as plt  # python付属の、グラフ等を描画するためのモジュール

#ちょっと奇妙ですが、プログラムの本文は次の文で始めます。
if __name__ == "__main__":

    #---- ０）気象データを取得--------------
    # 取得する気象要素の指定
    #  気象要素は、文字列で指定します。 
    nani = "TMP_mea"

    # データを取得する期間の指定
    #  2018年3月1日から7月31日までのデータを取得するには以下のように期間を指定します。
    itsu = ["2018-03-01", "2018-07-31" ]

    # 対象とする地点の指定
    doko = [ 36.0566, 36.0566, 140.125, 140.125]	#つくば(舘野)

    # 気象データの取得
    #　　気象データを取得するGetMetData関数の括弧の中に上記の変数を指定し、右辺に置きます。
    #　　左辺には関数の戻り値を置きます。順に、気象データ、日付、緯度、経度が格納されます。
    met, tim, lat, lon = AMD.GetMetData(nani, itsu, doko)	#気象データを取得
    #気象データは常に三次元(日付、緯度、経度)の入れ物に入れられて返されます。それを1次元(日付)の入れ物に入れ替えます。名前は一緒で構いません。
    T=met
    
    ntim = len(tim)  #何日分の気象データかを数えます。
    nlat = len(lat)  #南北方向（緯度方向）のメッシュ数を数えます。
    nlon = len(lon)  #東西方向（経度方向）のメッシュ数を数えます。

    #-----１）有効積算気温の計算 -------------# 
    Ts = 10.0       #基準温度
    Tccx = 950.0    #有効積算気温の上限値
    Tcc = np.zeros(ntim)   #有効積算気温の入れ物
 
    #-　t が 0（1番目）から ntim（選択された日数）になるまで、基準温度以上を積算していきます --#
   
    for t in range(0,ntim):
        # まず最初の日（t=0）を計算する
        if t == 0:
            Tcc[t] = max(T[t]-Ts, 0.0)
       # ２日目以降は、「t-1日目までの積算温度」に「t日目の有効温度」を足していく
        else:
            Tcc[t] = Tcc[t-1] + max(T[t]-Ts, 0.0)
       # 上限値に達した場合は、そこで計算をストップ
        if Tccx <= Tcc[t] :  
         break
        
    #------２）計算結果のグラフ表示 -----#
    # 描画領域の作成
    fig = plt.figure(num=None, figsize=(10,4))
    
    # x軸、y軸ラベルの指定
    plt.xlabel('Date')  # x軸
    plt.ylabel('Effective accumulated temp. [degC]') # y軸
    plt.title('N'+str(lat)+', E'+str(lon)+
              ' Effective accumulated temperature') # タイトル

    # 折れ線グラフを描画。
    # x軸に日付（tim）、y軸に有効積算気温（Tcc）をとり、線の色は赤、線幅は1.5
    plt.plot(tim,Tcc,'red',linewidth=1.5)
    
    # 図として保存
    plt.savefig('chart.png', dpi=150)
    
    #------３） 結果をcsvで書き出す-----------#
    # AMD.tools3 の　PutCSV_TS関数を使う
    AMD.PutCSV_TS(Tcc,tim, header='Date,EAT', filename='EAT-Tateno.csv')

    """
-----------AMD.Tools3より、PutCSV_TS の解説を抜粋------
概要：
    時系列のデータをCSV形式のファイルで出力する関数
書式：
    PutCSV_TS(Var, tim, header=None, filename='result.csv')
引数(必須)：
     Var：時系列の1次元配列データ。ただし、「Ver=np.array([V1,V2,..,Vn])」とすれ
        ば、n個の1次元配列V1,V2,..,Vnを一度に出力することができる。
     tim：時刻の見出しとして使用される一次元配列。第1列に行方向に出力される。
引数(必要に応じ指定)：
     header：引数に「header='moji,retsu'」として文字列を与えると、出力ファイルの
         第1行目にこの文字列が出力される。
     filename：引数に「filename='fairun_no_namae.csv'」として文字列を与えると、
         ファイルがこの名前で出力される。これを指定しない場合は、デフォルトの
         ファイル名「result.csv」が用いられる。
戻り値：なし
    """
